@@ -171,7 +171,11 @@ def set_dynamic_settings(s):
 
     # Ensure admin is last in the app order so that admin templates
     # are loaded in the correct order.
-    move("INSTALLED_APPS", "django.contrib.admin", len(s["INSTALLED_APPS"]))
+    admin_name = "django.contrib.admin"
+    try:
+        move("INSTALLED_APPS", admin_name, len(s["INSTALLED_APPS"]))
+    except ValueError:
+        pass
 
     # Ensure we have a test runner (removed in Django 1.6)
     s.setdefault("TEST_RUNNER", "django.test.simple.DjangoTestSuiteRunner")
