@@ -1,13 +1,17 @@
 from __future__ import unicode_literals
+from future.utils import with_metaclass
+
+from distutils.version import StrictVersion
 
 from django import get_version
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.db.models import Model, Field
+from django.db.models import Model, Field, get_model
+from django.db.models.signals import class_prepared
+from django.utils import six
 
 from mezzanine.utils.importing import import_dotted_path
-from future.utils import with_metaclass
-from distutils.version import StrictVersion
+
 
 # Backward compatibility with Django 1.5's "get_user_model".
 if StrictVersion(get_version()) >= StrictVersion('1.5'):
@@ -144,3 +148,57 @@ class ModelMixin(with_metaclass(ModelMixinBase, object)):
     inner ``Meta`` class with a ``mixin_for`` attribute containing the
     model that will be mixed into.
     """
+
+
+class LazyModelOperations(object):
+    """
+    This class connects itself to Django's class_prepared signal.
+    Pass a function and a model or model name to its ``add()`` method,
+    and the function will be called with the model as its only
+    parameter once the model has been loaded. If the model is already
+    loaded, the function is called immediately.
+
+    Adapted from ``django.db.models.fields.related`` and used in
+    ``mezzanine.generic.fields``.
+    """
+
+    def __init__(self):
+        self.pending_operations = {}
+        class_prepared.connect(self.signal_receiver)
+
+    @staticmethod
+    def model_key(model_or_name):
+        """
+        Returns an (app_label, model_name) tuple from a model or string.
+        """
+        if isinstance(model_or_name, six.string_types):
+            app_label, model_name = model_or_name.split(".")
+        else:
+            # It's actually a model class.
+            app_label = model_or_name._meta.app_label
+            model_name = model_or_name._meta.object_name
+        return app_label, model_name
+
+    def add(self, function, model_or_name):
+        model_key = self.model_key(model_or_name)
+
+        # If the model is already loaded, pass it to the function
+        # immediately. Otherwise, delay execution until the class
+        # is prepared.
+        model = get_model(*model_key, seed_cache=False, only_installed=False)
+        if model:
+            function(model)
+        else:
+            self.pending_operations.setdefault(model_key, []).append(function)
+
+    def signal_receiver(self, sender, **kwargs):
+        """
+        Receive ``class_prepared``, and pass the freshly prepared
+        model to each function waiting for it.
+        """
+        key = (sender._meta.app_label, sender.__name__)
+        for function in self.pending_operations.pop(key, []):
+            function(sender)
+
+
+lazy_model_ops = LazyModelOperations()
