@@ -113,10 +113,15 @@ def login_redirect(request):
         ignorable_nexts += (urls.SIGNUP_URL, urls.LOGIN_URL, urls.LOGOUT_URL)
     next = next_url(request) or ""
     if next in ignorable_nexts:
-        try:
-            next = reverse(settings.LOGIN_REDIRECT_URL)
-        except NoReverseMatch:
+        next = settings.LOGIN_REDIRECT_URL
+        if next == "/accounts/profile/":
+            # Use the homepage if LOGIN_REDIRECT_URL is Django's defaut.
             next = get_script_prefix()
+        else:
+            try:
+                next = reverse(next)
+            except NoReverseMatch:
+                pass
     return redirect(next)
 
 
